@@ -8,6 +8,10 @@
 #ifndef ACEGR_NPIPE_H_
 #define ACEGR_NPIPE_H_
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #ifndef EXIT_SUCCESS
 #  define EXIT_SUCCESS 0
 #endif
@@ -22,5 +26,9 @@ int ACEgrFlush (void);
 int ACEgrPrintf (const char*, ...);
 int ACEgrCommand (const char*);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* ACEGR_NPIPE_H */
 
