@@ -1,3 +1,5 @@
+#include <config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -11,13 +13,11 @@
 #endif
 
 static void put_annotation(int gno, FILE * pp, int embed);
-void put_region(FILE * pp, int embed);
+static void put_region(FILE * pp, int embed);
 
 extern  int pslwincr;
 extern  int pslwbegin;
 
-#define BADMAGIC 999999
-
 int realtime = 0;
 int change_gno;			/* if the graph number changes on read in */
 int change_type;		/* current set type */
@@ -26,7 +26,7 @@ int change_type;		/* current set type */
 /*
  * write out a set
  */
-int do_writesets(int gno, int setno, int imbed, char *fn, char *format)
+int do_writesets(int gno, int setno, int embed, char *fn, char *format)
 {
     int i, j, k, n, which_graph = gno, save_cg = cg, start, stop, set_start, set_stop;
     FILE *cp;
@@ -62,11 +62,11 @@ int do_writesets(int gno, int setno, int imbed, char *fn, char *format)
 	stop = which_graph;
     }
 
-    if (imbed) {
+    if (embed) {
 	if (start != stop) {
-	    putparms(-1, cp, imbed);
+	    putparms(-1, cp, embed);
 	} else {
-	    putparms(start, cp, imbed);
+	    putparms(start, cp, embed);
 	}
     }
 
@@ -164,12 +164,12 @@ int do_writesets(int gno, int setno, int imbed, char *fn, char *format)
     return 0;
 }
 
-void putparms(int gno, FILE * pp, int imbed)
+void putparms(int gno, FILE * pp, int embed)
 {
     int i, j, k, ming, maxg;
     int ps, pt, gh, gl, gt, fx, fy, px, py;
     double dsx, dsy;
-    char imbedstr[2], tmpstr1[128], tmpstr2[128];
+    char embedstr[2], tmpstr1[128], tmpstr2[128];
     framep f;
     legend leg;
     labels lab;
@@ -179,14 +179,16 @@ void putparms(int gno, FILE * pp, int imbed)
     view v;
     char *p1, *p2, *tmpbuf;
 
-    if (imbed) {
-	strcpy(imbedstr, "@");
+    if (embed) {
+	strcpy(embedstr, "@");
     } else {
-	imbedstr[0] = 0;
+	embedstr[0] = 0;
     }
-    fprintf(pp, "# xmgr parameter file\n");
-    fprintf(pp, "#\n");
+    fprintf(pp, "# ACE/gr parameter file\n");
     fprintf(pp, "#\n");
+    fprintf(pp, "# (Converted by grconvert)\n");
+
+    fprintf(pp, "%sversion 40001\n", embedstr);
 
     /* Print some global variables. Added by Henrik Seidel Tue Jun 10 16:47:14 MET DST 1997 */
     switch (page_layout) {
@@ -196,10 +198,10 @@ void putparms(int gno, FILE * pp, int imbed)
         case FIXED:      strcpy(tmpstr1, "fixed"); break;
         default:         strcpy(tmpstr1, "free"); break;
     }
-    fprintf(pp, "%spage layout %s\n", imbedstr, tmpstr1);
-    fprintf(pp, "%sps linewidth begin %d\n", imbedstr, pslwbegin);
-    fprintf(pp, "%sps linewidth increment %d\n", imbedstr, pslwincr);
-    fprintf(pp, "%shardcopy device %d\n", imbedstr, hdevice);
+    fprintf(pp, "%spage layout %s\n", embedstr, tmpstr1);
+    fprintf(pp, "%sps linewidth begin %d\n", embedstr, pslwbegin);
+    fprintf(pp, "%sps linewidth increment %d\n", embedstr, pslwincr);
+    fprintf(pp, "%shardcopy device %d\n", embedstr, hdevice);
     if (*description) {
         tmpbuf = (char *) malloc ((size_t) (strlen (description) + 1));
         if (tmpbuf == NULL) {
@@ -210,30 +212,30 @@ void putparms(int gno, FILE * pp, int imbed)
         p1 = tmpbuf;
         while ((p2 = strchr (p1, '\n')) != NULL) {
             *p2 = 0;
-            fprintf (pp, "%sdescription \"%s\"\n", imbedstr, escapequotes(p1));
+            fprintf (pp, "%sdescription \"%s\"\n", embedstr, escapequotes(p1));
             *p2 = '\n';
             p1 = p2;
             p1++;
         }
         if (*p1)
-            fprintf (pp, "%sdescription \"%s\"\n", imbedstr, escapequotes(p1));
+            fprintf (pp, "%sdescription \"%s\"\n", embedstr, escapequotes(p1));
         free (tmpbuf);
     }
     /* End of added globals */
 
-    fprintf(pp, "%spage %d\n", imbedstr, (int) (scrollper * 100));
-    fprintf(pp, "%spage inout %d\n", imbedstr, (int) (shexper * 100));
-    fprintf(pp, "%slink page %s\n", imbedstr, scrolling_islinked ? "on" : "off");
+    fprintf(pp, "%spage %d\n", embedstr, (int) (scrollper * 100));
+    fprintf(pp, "%spage inout %d\n", embedstr, (int) (shexper * 100));
+    fprintf(pp, "%slink page %s\n", embedstr, scrolling_islinked ? "on" : "off");
 
-    fprintf(pp, "%sdefault linestyle %d\n", imbedstr, grdefaults.lines);
-    fprintf(pp, "%sdefault linewidth %d\n", imbedstr, grdefaults.linew);
-    fprintf(pp, "%sdefault color %d\n", imbedstr, grdefaults.color);
-    fprintf(pp, "%sdefault char size %f\n", imbedstr, grdefaults.charsize);
-    fprintf(pp, "%sdefault font %d\n", imbedstr, grdefaults.font);
-    fprintf(pp, "%sdefault font source %d\n", imbedstr, grdefaults.fontsrc);
-    fprintf(pp, "%sdefault symbol size %f\n", imbedstr, grdefaults.symsize);
-    put_annotation(gno, pp, imbed);
-    put_region(pp, imbed);
+    fprintf(pp, "%sdefault linestyle %d\n", embedstr, grdefaults.lines);
+    fprintf(pp, "%sdefault linewidth %d\n", embedstr, grdefaults.linew);
+    fprintf(pp, "%sdefault color %d\n", embedstr, grdefaults.color);
+    fprintf(pp, "%sdefault char size %f\n", embedstr, grdefaults.charsize);
+    fprintf(pp, "%sdefault font %d\n", embedstr, grdefaults.font);
+    fprintf(pp, "%sdefault font source %d\n", embedstr, grdefaults.fontsrc);
+    fprintf(pp, "%sdefault symbol size %f\n", embedstr, grdefaults.symsize);
+    put_annotation(gno, pp, embed);
+    put_region(pp, embed);
     if (gno == -1) {
 	maxg = maxgraph - 1;
 	ming = 0;
@@ -256,103 +258,103 @@ void putparms(int gno, FILE * pp, int imbed)
 	    px = g[gno].px;
 	    py = g[gno].py;
 
-	    fprintf(pp, "%swith g%1d\n", imbedstr, gno);
+	    fprintf(pp, "%swith g%1d\n", embedstr, gno);
 
-	    fprintf(pp, "%sg%1d %s\n", imbedstr, gno, on_or_off(g[gno].active));
-	    fprintf(pp, "%sg%1d label %s\n", imbedstr, gno, on_or_off(gl));
-	    fprintf(pp, "%sg%1d hidden %s\n", imbedstr, gno, gh ? "true" : "false");
-	    fprintf(pp, "%sg%1d type %s\n", imbedstr, gno, graph_types(g[gno].type, 1));
-	    fprintf(pp, "%sg%1d autoscale type %s\n", imbedstr, gno, g[gno].auto_type == AUTO ? "AUTO" : "SPEC");
-	    fprintf(pp, "%sg%1d fixedpoint %s\n", imbedstr, gno, on_or_off(ps));
-	    fprintf(pp, "%sg%1d fixedpoint type %d\n", imbedstr, gno, pt);
-	    fprintf(pp, "%sg%1d fixedpoint xy %f, %f\n", imbedstr, gno, dsx, dsy);
+	    fprintf(pp, "%sg%1d %s\n", embedstr, gno, on_or_off(g[gno].active));
+	    fprintf(pp, "%sg%1d label %s\n", embedstr, gno, on_or_off(gl));
+	    fprintf(pp, "%sg%1d hidden %s\n", embedstr, gno, gh ? "true" : "false");
+	    fprintf(pp, "%sg%1d type %s\n", embedstr, gno, graph_types(g[gno].type, 1));
+	    fprintf(pp, "%sg%1d autoscale type %s\n", embedstr, gno, g[gno].auto_type == AUTO ? "AUTO" : "SPEC");
+	    fprintf(pp, "%sg%1d fixedpoint %s\n", embedstr, gno, on_or_off(ps));
+	    fprintf(pp, "%sg%1d fixedpoint type %d\n", embedstr, gno, pt);
+	    fprintf(pp, "%sg%1d fixedpoint xy %f, %f\n", embedstr, gno, dsx, dsy);
 	    strcpy(tmpstr1, get_format_types(fx));
 	    strcpy(tmpstr2, get_format_types(fy));
-	    fprintf(pp, "%sg%1d fixedpoint format %s %s\n", imbedstr, gno, tmpstr1, tmpstr2);
-	    fprintf(pp, "%sg%1d fixedpoint prec %d, %d\n", imbedstr, gno, px, py);
+	    fprintf(pp, "%sg%1d fixedpoint format %s %s\n", embedstr, gno, tmpstr1, tmpstr2);
+	    fprintf(pp, "%sg%1d fixedpoint prec %d, %d\n", embedstr, gno, px, py);
 
 	    get_graph_world(gno, &w);
-	    fprintf(pp, "%s    world xmin %.12g\n", imbedstr, w.xg1);
-	    fprintf(pp, "%s    world xmax %.12g\n", imbedstr, w.xg2);
-	    fprintf(pp, "%s    world ymin %.12g\n", imbedstr, w.yg1);
-	    fprintf(pp, "%s    world ymax %.12g\n", imbedstr, w.yg2);
+	    fprintf(pp, "%s    world xmin %.12g\n", embedstr, w.xg1);
+	    fprintf(pp, "%s    world xmax %.12g\n", embedstr, w.xg2);
+	    fprintf(pp, "%s    world ymin %.12g\n", embedstr, w.yg1);
+	    fprintf(pp, "%s    world ymax %.12g\n", embedstr, w.yg2);
 
 	    for (i = 0; i < g[gno].ws_top; i++) {
-		fprintf(pp, "%s    stack world %.9g, %.9g, %.9g, %.9g tick %g, %g, %g, %g\n", imbedstr,
+		fprintf(pp, "%s    stack world %.9g, %.9g, %.9g, %.9g tick %g, %g, %g, %g\n", embedstr,
 			g[gno].ws[i].w.xg1, g[gno].ws[i].w.xg2, g[gno].ws[i].w.yg1, g[gno].ws[i].w.yg2,
 			g[gno].ws[i].t[0].xg1, g[gno].ws[i].t[0].xg2, g[gno].ws[i].t[0].yg1, g[gno].ws[i].t[0].yg2);
 	    }
 
 	    get_graph_view(gno, &v);
-	    fprintf(pp, "%s    view xmin %f\n", imbedstr, v.xv1);
-	    fprintf(pp, "%s    view xmax %f\n", imbedstr, v.xv2);
-	    fprintf(pp, "%s    view ymin %f\n", imbedstr, v.yv1);
-	    fprintf(pp, "%s    view ymax %f\n", imbedstr, v.yv2);
+	    fprintf(pp, "%s    view xmin %f\n", embedstr, v.xv1);
+	    fprintf(pp, "%s    view xmax %f\n", embedstr, v.xv2);
+	    fprintf(pp, "%s    view ymin %f\n", embedstr, v.yv1);
+	    fprintf(pp, "%s    view ymax %f\n", embedstr, v.yv2);
 
 	    get_graph_labels(gno, &lab);
-	    fprintf(pp, "%s    title \"%s\"\n", imbedstr, escapequotes(lab.title.s));
-	    fprintf(pp, "%s    title font %d\n", imbedstr, lab.title.font);
-	    fprintf(pp, "%s    title size %f\n", imbedstr, lab.title.charsize);
-	    fprintf(pp, "%s    title color %d\n", imbedstr, lab.title.color);
-	    fprintf(pp, "%s    title linewidth %d\n", imbedstr, lab.title.linew);
-	    fprintf(pp, "%s    subtitle \"%s\"\n", imbedstr, escapequotes(lab.stitle.s));
-	    fprintf(pp, "%s    subtitle font %d\n", imbedstr, lab.stitle.font);
-	    fprintf(pp, "%s    subtitle size %f\n", imbedstr, lab.stitle.charsize);
-	    fprintf(pp, "%s    subtitle color %d\n", imbedstr, lab.stitle.color);
-	    fprintf(pp, "%s    subtitle linewidth %d\n", imbedstr, lab.stitle.linew);
+	    fprintf(pp, "%s    title \"%s\"\n", embedstr, escapequotes(lab.title.s));
+	    fprintf(pp, "%s    title font %d\n", embedstr, lab.title.font);
+	    fprintf(pp, "%s    title size %f\n", embedstr, lab.title.charsize);
+	    fprintf(pp, "%s    title color %d\n", embedstr, lab.title.color);
+	    fprintf(pp, "%s    title linewidth %d\n", embedstr, lab.title.linew);
+	    fprintf(pp, "%s    subtitle \"%s\"\n", embedstr, escapequotes(lab.stitle.s));
+	    fprintf(pp, "%s    subtitle font %d\n", embedstr, lab.stitle.font);
+	    fprintf(pp, "%s    subtitle size %f\n", embedstr, lab.stitle.charsize);
+	    fprintf(pp, "%s    subtitle color %d\n", embedstr, lab.stitle.color);
+	    fprintf(pp, "%s    subtitle linewidth %d\n", embedstr, lab.stitle.linew);
 
 	    for (i = 0; i < g[gno].maxplot; i++) {
 		get_graph_plotarr(gno, i, &p);
 		if (isactive_set(gno, i)) {
 /* setting the type here causes big problems
-		    fprintf(pp, "%s    s%1d type %s\n", imbedstr, i, (char *) set_types(p.type));
+		    fprintf(pp, "%s    s%1d type %s\n", embedstr, i, (char *) set_types(p.type));
 */
-		    fprintf(pp, "%s    s%1d symbol %d\n", imbedstr, i, p.sym);
-		    fprintf(pp, "%s    s%1d symbol size %f\n", imbedstr, i, p.symsize);
-		    fprintf(pp, "%s    s%1d symbol fill %d\n", imbedstr, i, p.symfill);
-		    fprintf(pp, "%s    s%1d symbol color %d\n", imbedstr, i, p.symcolor);
-		    fprintf(pp, "%s    s%1d symbol linewidth %d\n", imbedstr, i, p.symlinew);
-		    fprintf(pp, "%s    s%1d symbol linestyle %d\n", imbedstr, i, p.symlines);
-		    fprintf(pp, "%s    s%1d symbol center %s\n", imbedstr, i, p.symdot ? "true" : "false");
-		    fprintf(pp, "%s    s%1d symbol char %d\n", imbedstr, i, p.symchar);
-		    fprintf(pp, "%s    s%1d skip %d\n", imbedstr, i, p.symskip);
-		    fprintf(pp, "%s    s%1d linestyle %d\n", imbedstr, i, p.lines);
-		    fprintf(pp, "%s    s%1d linewidth %d\n", imbedstr, i, p.linew);
-		    fprintf(pp, "%s    s%1d color %d\n", imbedstr, i, p.color);
-		    fprintf(pp, "%s    s%1d fill %d\n", imbedstr, i, p.fill);
-		    fprintf(pp, "%s    s%1d fill with %s\n", imbedstr, i,
+		    fprintf(pp, "%s    s%1d symbol %d\n", embedstr, i, p.sym);
+		    fprintf(pp, "%s    s%1d symbol size %f\n", embedstr, i, p.symsize);
+		    fprintf(pp, "%s    s%1d symbol fill %d\n", embedstr, i, p.symfill);
+		    fprintf(pp, "%s    s%1d symbol color %d\n", embedstr, i, p.symcolor);
+		    fprintf(pp, "%s    s%1d symbol linewidth %d\n", embedstr, i, p.symlinew);
+		    fprintf(pp, "%s    s%1d symbol linestyle %d\n", embedstr, i, p.symlines);
+		    fprintf(pp, "%s    s%1d symbol center %s\n", embedstr, i, p.symdot ? "true" : "false");
+		    fprintf(pp, "%s    s%1d symbol char %d\n", embedstr, i, p.symchar);
+		    fprintf(pp, "%s    s%1d skip %d\n", embedstr, i, p.symskip);
+		    fprintf(pp, "%s    s%1d linestyle %d\n", embedstr, i, p.lines);
+		    fprintf(pp, "%s    s%1d linewidth %d\n", embedstr, i, p.linew);
+		    fprintf(pp, "%s    s%1d color %d\n", embedstr, i, p.color);
+		    fprintf(pp, "%s    s%1d fill %d\n", embedstr, i, p.fill);
+		    fprintf(pp, "%s    s%1d fill with %s\n", embedstr, i,
 			    p.fillusing == COLOR ? "color" : "pattern");
-		    fprintf(pp, "%s    s%1d fill color %d\n", imbedstr, i, p.fillcolor);
-		    fprintf(pp, "%s    s%1d fill pattern %d\n", imbedstr, i, p.fillpattern);
+		    fprintf(pp, "%s    s%1d fill color %d\n", embedstr, i, p.fillcolor);
+		    fprintf(pp, "%s    s%1d fill pattern %d\n", embedstr, i, p.fillpattern);
 		    switch (p.errbarxy) {
 		    case TOP:
-			fprintf(pp, "%s    s%1d errorbar type TOP\n", imbedstr, i);
+			fprintf(pp, "%s    s%1d errorbar type TOP\n", embedstr, i);
 			break;
 		    case BOTTOM:
-			fprintf(pp, "%s    s%1d errorbar type BOTTOM\n", imbedstr, i);
+			fprintf(pp, "%s    s%1d errorbar type BOTTOM\n", embedstr, i);
 			break;
 		    case LEFT:
-			fprintf(pp, "%s    s%1d errorbar type LEFT\n", imbedstr, i);
+			fprintf(pp, "%s    s%1d errorbar type LEFT\n", embedstr, i);
 			break;
 		    case RIGHT:
-			fprintf(pp, "%s    s%1d errorbar type RIGHT\n", imbedstr, i);
+			fprintf(pp, "%s    s%1d errorbar type RIGHT\n", embedstr, i);
 			break;
 		    case BOTH:
-			fprintf(pp, "%s    s%1d errorbar type BOTH\n", imbedstr, i);
+			fprintf(pp, "%s    s%1d errorbar type BOTH\n", embedstr, i);
 			break;
 		    }
-		    fprintf(pp, "%s    s%1d errorbar length %f\n", imbedstr, i, p.errbarper);
-		    fprintf(pp, "%s    s%1d errorbar linewidth %d\n", imbedstr, i, p.errbar_linew);
-		    fprintf(pp, "%s    s%1d errorbar linestyle %d\n", imbedstr, i, p.errbar_lines);
-		    fprintf(pp, "%s    s%1d errorbar riser %s\n", imbedstr, i, p.errbar_riser == ON ? "on" : "off");
-		    fprintf(pp, "%s    s%1d errorbar riser linewidth %d\n", imbedstr, i, p.errbar_riser_linew);
-		    fprintf(pp, "%s    s%1d errorbar riser linestyle %d\n", imbedstr, i, p.errbar_riser_lines);
-		    fprintf(pp, "%s    s%1d xyz %f, %f\n", imbedstr, i, p.zmin, p.zmax);
+		    fprintf(pp, "%s    s%1d errorbar length %f\n", embedstr, i, p.errbarper);
+		    fprintf(pp, "%s    s%1d errorbar linewidth %d\n", embedstr, i, p.errbar_linew);
+		    fprintf(pp, "%s    s%1d errorbar linestyle %d\n", embedstr, i, p.errbar_lines);
+		    fprintf(pp, "%s    s%1d errorbar riser %s\n", embedstr, i, p.errbar_riser == ON ? "on" : "off");
+		    fprintf(pp, "%s    s%1d errorbar riser linewidth %d\n", embedstr, i, p.errbar_riser_linew);
+		    fprintf(pp, "%s    s%1d errorbar riser linestyle %d\n", embedstr, i, p.errbar_riser_lines);
+		    fprintf(pp, "%s    s%1d xyz %f, %f\n", embedstr, i, p.zmin, p.zmax);
 		    if (is_hotlinked(gno, i)) {
-			fprintf(pp, "%s    s%1d link %s \"%s\"\n", imbedstr, i,
+			fprintf(pp, "%s    s%1d link %s \"%s\"\n", embedstr, i,
 			  p.hotsrc == DISK ? "disk" : "pipe", p.hotfile);
 		    }
-		    fprintf(pp, "%s    s%1d comment \"%s\"\n", imbedstr, i, p.comments);
+		    fprintf(pp, "%s    s%1d comment \"%s\"\n", embedstr, i, p.comments);
 		}
 	    }
 
@@ -361,34 +363,34 @@ void putparms(int gno, FILE * pp, int imbed)
 		case 0:
 		    get_graph_tickmarks(gno, &t, X_AXIS);
 		    if (t.active == OFF) {
-			fprintf(pp, "%s    xaxis off\n", imbedstr);
+			fprintf(pp, "%s    xaxis off\n", embedstr);
 			continue;
 		    }
-		    sprintf(buf, "%s    xaxis ", imbedstr);
+		    sprintf(buf, "%s    xaxis ", embedstr);
 		    break;
 		case 1:
 		    get_graph_tickmarks(gno, &t, Y_AXIS);
 		    if (t.active == OFF) {
-			fprintf(pp, "%s    yaxis off\n", imbedstr);
+			fprintf(pp, "%s    yaxis off\n", embedstr);
 			continue;
 		    }
-		    sprintf(buf, "%s    yaxis ", imbedstr);
+		    sprintf(buf, "%s    yaxis ", embedstr);
 		    break;
 		case 2:
 		    get_graph_tickmarks(gno, &t, ZX_AXIS);
 		    if (t.active == OFF) {
-			fprintf(pp, "%s    zeroxaxis off\n", imbedstr);
+			fprintf(pp, "%s    zeroxaxis off\n", embedstr);
 			continue;
 		    }
-		    sprintf(buf, "%s    zeroxaxis ", imbedstr);
+		    sprintf(buf, "%s    zeroxaxis ", embedstr);
 		    break;
 		case 3:
 		    get_graph_tickmarks(gno, &t, ZY_AXIS);
 		    if (t.active == OFF) {
-			fprintf(pp, "%s    zeroyaxis off\n", imbedstr);
+			fprintf(pp, "%s    zeroyaxis off\n", embedstr);
 			continue;
 		    }
-		    sprintf(buf, "%s    zeroyaxis ", imbedstr);
+		    sprintf(buf, "%s    zeroyaxis ", embedstr);
 		    break;
 		}
 
@@ -540,210 +542,210 @@ void putparms(int gno, FILE * pp, int imbed)
 	    }
 
 	    get_graph_legend(gno, &leg);
-	    fprintf(pp, "%s    legend %s\n", imbedstr, on_or_off(leg.active));
-	    fprintf(pp, "%s    legend loctype %s\n", imbedstr, w_or_v(leg.loctype));
-	    fprintf(pp, "%s    legend layout %d\n", imbedstr, leg.layout);
-	    fprintf(pp, "%s    legend vgap %d\n", imbedstr, leg.vgap);
-	    fprintf(pp, "%s    legend hgap %d\n", imbedstr, leg.hgap);
-	    fprintf(pp, "%s    legend length %d\n", imbedstr, leg.len);
-	    fprintf(pp, "%s    legend box %s\n", imbedstr, on_or_off(leg.box));
-	    fprintf(pp, "%s    legend box fill %s\n", imbedstr, on_or_off(leg.box));
-	    fprintf(pp, "%s    legend box fill with %s\n", imbedstr, leg.boxfillusing == COLOR ? "color" : "pattern");
-	    fprintf(pp, "%s    legend box fill color %d\n", imbedstr, leg.boxfillcolor);
-	    fprintf(pp, "%s    legend box fill pattern %d\n", imbedstr, leg.boxfillpat);
-	    fprintf(pp, "%s    legend box color %d\n", imbedstr, leg.boxlcolor);
-	    fprintf(pp, "%s    legend box linewidth %d\n", imbedstr, leg.boxlinew);
-	    fprintf(pp, "%s    legend box linestyle %d\n", imbedstr, leg.boxlines);
-	    fprintf(pp, "%s    legend x1 %.12g\n", imbedstr, leg.legx);
-	    fprintf(pp, "%s    legend y1 %.12g\n", imbedstr, leg.legy);
-	    fprintf(pp, "%s    legend font %d\n", imbedstr, leg.font);
-	    fprintf(pp, "%s    legend char size %f\n", imbedstr, leg.charsize);
-	    fprintf(pp, "%s    legend linestyle %d\n", imbedstr, leg.lines);
-	    fprintf(pp, "%s    legend linewidth %d\n", imbedstr, leg.linew);
-	    fprintf(pp, "%s    legend color %d\n", imbedstr, leg.color);
+	    fprintf(pp, "%s    legend %s\n", embedstr, on_or_off(leg.active));
+	    fprintf(pp, "%s    legend loctype %s\n", embedstr, w_or_v(leg.loctype));
+	    fprintf(pp, "%s    legend layout %d\n", embedstr, leg.layout);
+	    fprintf(pp, "%s    legend vgap %d\n", embedstr, leg.vgap);
+	    fprintf(pp, "%s    legend hgap %d\n", embedstr, leg.hgap);
+	    fprintf(pp, "%s    legend length %d\n", embedstr, leg.len);
+	    fprintf(pp, "%s    legend box %s\n", embedstr, on_or_off(leg.box));
+	    fprintf(pp, "%s    legend box fill %s\n", embedstr, on_or_off(leg.box));
+	    fprintf(pp, "%s    legend box fill with %s\n", embedstr, leg.boxfillusing == COLOR ? "color" : "pattern");
+	    fprintf(pp, "%s    legend box fill color %d\n", embedstr, leg.boxfillcolor);
+	    fprintf(pp, "%s    legend box fill pattern %d\n", embedstr, leg.boxfillpat);
+	    fprintf(pp, "%s    legend box color %d\n", embedstr, leg.boxlcolor);
+	    fprintf(pp, "%s    legend box linewidth %d\n", embedstr, leg.boxlinew);
+	    fprintf(pp, "%s    legend box linestyle %d\n", embedstr, leg.boxlines);
+	    fprintf(pp, "%s    legend x1 %.12g\n", embedstr, leg.legx);
+	    fprintf(pp, "%s    legend y1 %.12g\n", embedstr, leg.legy);
+	    fprintf(pp, "%s    legend font %d\n", embedstr, leg.font);
+	    fprintf(pp, "%s    legend char size %f\n", embedstr, leg.charsize);
+	    fprintf(pp, "%s    legend linestyle %d\n", embedstr, leg.lines);
+	    fprintf(pp, "%s    legend linewidth %d\n", embedstr, leg.linew);
+	    fprintf(pp, "%s    legend color %d\n", embedstr, leg.color);
 	    for (i = 0; i < maxplot; i++) {
 		if (isactive_set(gno, i)) {
 		    if (strlen(g[gno].p[i].lstr)) {
 			fprintf(pp, "%s    legend string %d \"%s\"\n", 
-				imbedstr, i, escapequotes(g[gno].p[i].lstr));
+				embedstr, i, escapequotes(g[gno].p[i].lstr));
 		    }
 		}
 	    }
 
 	    get_graph_framep(gno, &f);
-	    fprintf(pp, "%s    frame %s\n", imbedstr, on_or_off(f.active));
-	    fprintf(pp, "%s    frame type %d\n", imbedstr, f.type);
-	    fprintf(pp, "%s    frame linestyle %d\n", imbedstr, f.lines);
-	    fprintf(pp, "%s    frame linewidth %d\n", imbedstr, f.linew);
-	    fprintf(pp, "%s    frame color %d\n", imbedstr, f.color);
-	    fprintf(pp, "%s    frame fill %s\n", imbedstr, on_or_off(f.fillbg));
-	    fprintf(pp, "%s    frame background color %d\n", imbedstr, f.bgcolor);
+	    fprintf(pp, "%s    frame %s\n", embedstr, on_or_off(f.active));
+	    fprintf(pp, "%s    frame type %d\n", embedstr, f.type);
+	    fprintf(pp, "%s    frame linestyle %d\n", embedstr, f.lines);
+	    fprintf(pp, "%s    frame linewidth %d\n", embedstr, f.linew);
+	    fprintf(pp, "%s    frame color %d\n", embedstr, f.color);
+	    fprintf(pp, "%s    frame fill %s\n", embedstr, on_or_off(f.fillbg));
+	    fprintf(pp, "%s    frame background color %d\n", embedstr, f.bgcolor);
 	}
     }
 }
 
-void put_annotation(int gno, FILE * pp, int imbed)
+static void put_annotation(int gno, FILE * pp, int embed)
 {
     int i;
     boxtype b;
     linetype l;
     ellipsetype e;
     plotstr s;
-    char imbedstr[2];
+    char embedstr[2];
 
-    if (imbed) {
-	strcpy(imbedstr, "@");
+    if (embed) {
+	strcpy(embedstr, "@");
     } else {
-	imbedstr[0] = 0;
+	embedstr[0] = 0;
     }
     for (i = 0; i < maxboxes; i++) {
 	get_graph_box(i, &b);
 	if (b.active == ON) {
-	    fprintf(pp, "%swith box\n", imbedstr);
-	    fprintf(pp, "%s    box on\n", imbedstr);
-	    fprintf(pp, "%s    box loctype %s\n", imbedstr, w_or_v(b.loctype));
+	    fprintf(pp, "%swith box\n", embedstr);
+	    fprintf(pp, "%s    box on\n", embedstr);
+	    fprintf(pp, "%s    box loctype %s\n", embedstr, w_or_v(b.loctype));
 	    if (b.loctype == WORLD) {
-		fprintf(pp, "%s    box g%1d\n", imbedstr, b.gno);
+		fprintf(pp, "%s    box g%1d\n", embedstr, b.gno);
 	    }
-	    fprintf(pp, "%s    box %.12g, %.12g, %.12g, %.12g\n", imbedstr, b.x1, b.y1, b.x2, b.y2);
-	    fprintf(pp, "%s    box linestyle %d\n", imbedstr, b.lines);
-	    fprintf(pp, "%s    box linewidth %d\n", imbedstr, b.linew);
-	    fprintf(pp, "%s    box color %d\n", imbedstr, b.color);
+	    fprintf(pp, "%s    box %.12g, %.12g, %.12g, %.12g\n", embedstr, b.x1, b.y1, b.x2, b.y2);
+	    fprintf(pp, "%s    box linestyle %d\n", embedstr, b.lines);
+	    fprintf(pp, "%s    box linewidth %d\n", embedstr, b.linew);
+	    fprintf(pp, "%s    box color %d\n", embedstr, b.color);
 	    switch (b.fill) {
 	    case NONE:
-		fprintf(pp, "%s    box fill none\n", imbedstr);
+		fprintf(pp, "%s    box fill none\n", embedstr);
 		break;
 	    case COLOR:
-		fprintf(pp, "%s    box fill color\n", imbedstr);
+		fprintf(pp, "%s    box fill color\n", embedstr);
 		break;
 	    case PATTERN:
-		fprintf(pp, "%s    box fill pattern\n", imbedstr);
+		fprintf(pp, "%s    box fill pattern\n", embedstr);
 		break;
 	    }
-	    fprintf(pp, "%s    box fill color %d\n", imbedstr, b.fillcolor);
-	    fprintf(pp, "%s    box fill pattern %d\n", imbedstr, b.fillpattern);
-	    fprintf(pp, "%sbox def\n", imbedstr);
+	    fprintf(pp, "%s    box fill color %d\n", embedstr, b.fillcolor);
+	    fprintf(pp, "%s    box fill pattern %d\n", embedstr, b.fillpattern);
+	    fprintf(pp, "%sbox def\n", embedstr);
 	}
     }
 
     for (i = 0; i < maxellipses; i++) {
 	get_graph_ellipse(i, &e);
 	if (e.active == ON) {
-	    fprintf(pp, "%swith ellipse\n", imbedstr);
-	    fprintf(pp, "%s    ellipse on\n", imbedstr);
-	    fprintf(pp, "%s    ellipse loctype %s\n", imbedstr, w_or_v(e.loctype));
+	    fprintf(pp, "%swith ellipse\n", embedstr);
+	    fprintf(pp, "%s    ellipse on\n", embedstr);
+	    fprintf(pp, "%s    ellipse loctype %s\n", embedstr, w_or_v(e.loctype));
 	    if (e.loctype == WORLD) {
-		fprintf(pp, "%s    ellipse g%1d\n", imbedstr, e.gno);
+		fprintf(pp, "%s    ellipse g%1d\n", embedstr, e.gno);
 	    }
-	    fprintf(pp, "%s    ellipse %.12g, %.12g, %.12g, %.12g\n", imbedstr, e.x1, e.y1, e.x2, e.y2);
-	    fprintf(pp, "%s    ellipse linestyle %d\n", imbedstr, e.lines);
-	    fprintf(pp, "%s    ellipse linewidth %d\n", imbedstr, e.linew);
-	    fprintf(pp, "%s    ellipse color %d\n", imbedstr, e.color);
+	    fprintf(pp, "%s    ellipse %.12g, %.12g, %.12g, %.12g\n", embedstr, e.x1, e.y1, e.x2, e.y2);
+	    fprintf(pp, "%s    ellipse linestyle %d\n", embedstr, e.lines);
+	    fprintf(pp, "%s    ellipse linewidth %d\n", embedstr, e.linew);
+	    fprintf(pp, "%s    ellipse color %d\n", embedstr, e.color);
 	    switch (e.fill) {
 	    case NONE:
-		fprintf(pp, "%s    ellipse fill none\n", imbedstr);
+		fprintf(pp, "%s    ellipse fill none\n", embedstr);
 		break;
 	    case COLOR:
-		fprintf(pp, "%s    ellipse fill color\n", imbedstr);
+		fprintf(pp, "%s    ellipse fill color\n", embedstr);
 		break;
 	    case PATTERN:
-		fprintf(pp, "%s    ellipse fill pattern\n", imbedstr);
+		fprintf(pp, "%s    ellipse fill pattern\n", embedstr);
 		break;
 	    }
-	    fprintf(pp, "%s    ellipse fill color %d\n", imbedstr, e.fillcolor);
-	    fprintf(pp, "%s    ellipse fill pattern %d\n", imbedstr, e.fillpattern);
-	    fprintf(pp, "%sellipse def\n", imbedstr);
+	    fprintf(pp, "%s    ellipse fill color %d\n", embedstr, e.fillcolor);
+	    fprintf(pp, "%s    ellipse fill pattern %d\n", embedstr, e.fillpattern);
+	    fprintf(pp, "%sellipse def\n", embedstr);
 	}
     }
    for (i = 0; i < maxlines; i++) {
 	get_graph_line(i, &l);
 	if (l.active == ON) {
-	    fprintf(pp, "%swith line\n", imbedstr);
-	    fprintf(pp, "%s    line on\n", imbedstr);
-	    fprintf(pp, "%s    line loctype %s\n", imbedstr, w_or_v(l.loctype));
+	    fprintf(pp, "%swith line\n", embedstr);
+	    fprintf(pp, "%s    line on\n", embedstr);
+	    fprintf(pp, "%s    line loctype %s\n", embedstr, w_or_v(l.loctype));
 	    if (l.loctype == WORLD) {
-		fprintf(pp, "%s    line g%1d\n", imbedstr, l.gno);
+		fprintf(pp, "%s    line g%1d\n", embedstr, l.gno);
 	    }
-	    fprintf(pp, "%s    line %.12g, %.12g, %.12g, %.12g\n", imbedstr, l.x1, l.y1, l.x2, l.y2);
-	    fprintf(pp, "%s    line linewidth %d\n", imbedstr, l.linew);
-	    fprintf(pp, "%s    line linestyle %d\n", imbedstr, l.lines);
-	    fprintf(pp, "%s    line color %d\n", imbedstr, l.color);
-	    fprintf(pp, "%s    line arrow %d\n", imbedstr, l.arrow);
-	    fprintf(pp, "%s    line arrow size %f\n", imbedstr, l.asize);
-	    fprintf(pp, "%s    line arrow type %d\n", imbedstr, l.atype);
-	    fprintf(pp, "%sline def\n", imbedstr);
+	    fprintf(pp, "%s    line %.12g, %.12g, %.12g, %.12g\n", embedstr, l.x1, l.y1, l.x2, l.y2);
+	    fprintf(pp, "%s    line linewidth %d\n", embedstr, l.linew);
+	    fprintf(pp, "%s    line linestyle %d\n", embedstr, l.lines);
+	    fprintf(pp, "%s    line color %d\n", embedstr, l.color);
+	    fprintf(pp, "%s    line arrow %d\n", embedstr, l.arrow);
+	    fprintf(pp, "%s    line arrow size %f\n", embedstr, l.asize);
+	    fprintf(pp, "%s    line arrow type %d\n", embedstr, l.atype);
+	    fprintf(pp, "%sline def\n", embedstr);
 	}
     }
 
     for (i = 0; i < maxstr; i++) {
 	get_graph_string(i, &s);
 	if (s.active == ON && s.s[0]) {
-	    fprintf(pp, "%swith string\n", imbedstr);
-	    fprintf(pp, "%s    string on\n", imbedstr);
-	    fprintf(pp, "%s    string loctype %s\n", imbedstr, w_or_v(s.loctype));
+	    fprintf(pp, "%swith string\n", embedstr);
+	    fprintf(pp, "%s    string on\n", embedstr);
+	    fprintf(pp, "%s    string loctype %s\n", embedstr, w_or_v(s.loctype));
 	    if (s.loctype == WORLD) {
-		fprintf(pp, "%s    string g%1d\n", imbedstr, s.gno);
+		fprintf(pp, "%s    string g%1d\n", embedstr, s.gno);
 	    }
-	    fprintf(pp, "%s    string %.12g, %.12g\n", imbedstr, s.x, s.y);
-	    fprintf(pp, "%s    string linewidth %d\n", imbedstr, s.linew);
-	    fprintf(pp, "%s    string color %d\n", imbedstr, s.color);
-	    fprintf(pp, "%s    string rot %d\n", imbedstr, s.rot);
-	    fprintf(pp, "%s    string font %d\n", imbedstr, s.font);
-	    fprintf(pp, "%s    string just %d\n", imbedstr, s.just);
-	    fprintf(pp, "%s    string char size %f\n", imbedstr, s.charsize);
-	    fprintf(pp, "%sstring def \"%s\"\n", imbedstr, escapequotes(s.s));
+	    fprintf(pp, "%s    string %.12g, %.12g\n", embedstr, s.x, s.y);
+	    fprintf(pp, "%s    string linewidth %d\n", embedstr, s.linew);
+	    fprintf(pp, "%s    string color %d\n", embedstr, s.color);
+	    fprintf(pp, "%s    string rot %d\n", embedstr, s.rot);
+	    fprintf(pp, "%s    string font %d\n", embedstr, s.font);
+	    fprintf(pp, "%s    string just %d\n", embedstr, s.just);
+	    fprintf(pp, "%s    string char size %f\n", embedstr, s.charsize);
+	    fprintf(pp, "%sstring def \"%s\"\n", embedstr, escapequotes(s.s));
 	}
     }
 }
 
-void put_region(FILE * pp, int imbed)
+static void put_region(FILE * pp, int embed)
 {
     int i, j;
-    char imbedstr[2];
+    char embedstr[2];
 
-    if (imbed) {
-	strcpy(imbedstr, "@");
+    if (embed) {
+	strcpy(embedstr, "@");
     } else {
-	imbedstr[0] = 0;
+	embedstr[0] = 0;
     }
     for (i = 0; i < MAXREGION; i++) {
 	if (rg[i].active == ON) {
-	    fprintf(pp, "%sr%1d ON\n", imbedstr, i);
+	    fprintf(pp, "%sr%1d ON\n", embedstr, i);
 	    switch (rg[i].type) {
 	    case ABOVE:
-		fprintf(pp, "%sr%1d type above\n", imbedstr, i);
+		fprintf(pp, "%sr%1d type above\n", embedstr, i);
 		break;
 	    case BELOW:
-		fprintf(pp, "%sr%1d type below\n", imbedstr, i);
+		fprintf(pp, "%sr%1d type below\n", embedstr, i);
 		break;
 	    case LEFT:
-		fprintf(pp, "%sr%1d type left\n", imbedstr, i);
+		fprintf(pp, "%sr%1d type left\n", embedstr, i);
 		break;
 	    case RIGHT:
-		fprintf(pp, "%sr%1d type right\n", imbedstr, i);
+		fprintf(pp, "%sr%1d type right\n", embedstr, i);
 		break;
 	    case POLYI:
-		fprintf(pp, "%sr%1d type polyi\n", imbedstr, i);
+		fprintf(pp, "%sr%1d type polyi\n", embedstr, i);
 		break;
 	    case POLYO:
-		fprintf(pp, "%sr%1d type polyo\n", imbedstr, i);
+		fprintf(pp, "%sr%1d type polyo\n", embedstr, i);
 		break;
 	    }
-	    fprintf(pp, "%sr%1d linestyle %d\n", imbedstr, i, rg[i].lines);
-	    fprintf(pp, "%sr%1d linewidth %d\n", imbedstr, i, rg[i].linew);
-	    fprintf(pp, "%sr%1d color %d\n", imbedstr, i, rg[i].color);
+	    fprintf(pp, "%sr%1d linestyle %d\n", embedstr, i, rg[i].lines);
+	    fprintf(pp, "%sr%1d linewidth %d\n", embedstr, i, rg[i].linew);
+	    fprintf(pp, "%sr%1d color %d\n", embedstr, i, rg[i].color);
 	    if (rg[i].type != POLYI && rg[i].type != POLYO) {
-		fprintf(pp, "%sr%1d line %.12g, %.12g, %.12g, %.12g\n", imbedstr, i, rg[i].x1, rg[i].y1, rg[i].x2, rg[i].y2);
+		fprintf(pp, "%sr%1d line %.12g, %.12g, %.12g, %.12g\n", embedstr, i, rg[i].x1, rg[i].y1, rg[i].x2, rg[i].y2);
 	    } else {
 		if (rg[i].x != NULL) {
 		    for (j = 0; j < rg[i].n; j++) {
-			fprintf(pp, "%sr%1d xy %.12g, %.12g\n", imbedstr, i, rg[i].x[j], rg[i].y[j]);
+			fprintf(pp, "%sr%1d xy %.12g, %.12g\n", embedstr, i, rg[i].x[j], rg[i].y[j]);
 		    }
 		}
 	    }
 	    for (j = 0; j < maxgraph; j++) {
 		if (rg[i].linkto[j] == TRUE) {
-		    fprintf(pp, "%slink r%1d to g%1d\n", imbedstr, i, j);
+		    fprintf(pp, "%slink r%1d to g%1d\n", embedstr, i, j);
 		}
 	    }
 	}
