@@ -67,76 +67,6 @@ void do_histo_command(int fromset, int toset, int tograph,
     do_histo(fromset, toset, tograph, binw, minb, minb + nbins * binw, 0);
 }
 
-/*
- * evaluate a formula
-void do_compute(int setno, int loadto, int graphto, char *fstr)
-{
-    int i, idraw = 0, itmp = setno;
-
-    if (graphto < 0) {
-	graphto = cg;
-    }
-    if (strlen(fstr) == 0) {
-	errmsg("Define formula first");
-	return;
-    }
-    if (setno == SET_SELECT_ALL) {
-	for (i = 0; i < g[cg].maxplot; i++) {
-	    if (isactive_set(cg, i)) {
-		if (formula(cg, i, fstr)) {
-		    sprintf(buf, "\nERROR: computing %s on set %d\n", fstr, i);
-		    stufftext(buf, STUFF_START);
-		    return;
-		}
-		sprintf(buf, "\nComputed %s on set %d\n", fstr, i);
-		stufftext(buf, STUFF_START);
-		idraw = 1;
-	    }
-	}
-    } else if (isactive_set(cg, setno)) {
-	if (loadto) {
-	    loadto = nextset(graphto);
-	    if (loadto != -1) {
-		do_copyset(cg, setno, graphto, loadto);
-		setno = loadto;
-	    } else {
-		return;
-	    }
-	} else if (graphto != cg) {
-	    loadto = setno;
-	    if (isactive_set(graphto, loadto)) {
-		killset(graphto, loadto);
-	    }
-	    do_copyset(cg, setno, graphto, loadto);
-	    setno = loadto;
-	}
-	if (formula(graphto, setno, fstr)) {
-	    sprintf(buf, "\nERROR: computing %s on set %d\n", fstr, setno);
-	    stufftext(buf, STUFF_START);
-	    if (loadto != setno) {
-		killset(graphto, loadto);
-	    }
-	    return;
-	}
-	sprintf(buf, "\nComputed %s on set %d, result to set %d\n", fstr, itmp, setno);
-	stufftext(buf, STUFF_START);
-	if (!isactive_graph(graphto)) {
-	    set_graph_active(graphto);
-	}
-	idraw = 1;
-    }
-    if (idraw) {
-#ifdef NONE_GUI
-	;
-#else
-	drawgraph();
-#endif
-    } else {
-	errmsg("Set(s) not active");
-    }
-}
- */
-
 /*
  * evaluate a formula
  */
@@ -168,7 +98,7 @@ int do_compute(int setno, int loadto, int graphto, char *fstr)
 	    setno = loadto;
 	}
 	if (formula(graphto, setno, fstr)) {
-	    if (loadto != setno) {
+	    if (graphto != cg || loadto != setno) {
 		killset(graphto, loadto);
 	    }
 	    return -1;
