@@ -249,7 +249,7 @@ void refresh(Widget w, XtPointer client_data, XmDrawingAreaCallbackStruct * cbs)
 /*
  * resize proc
  */
-void resize(Widget w, caddr_t data, XEvent * event)
+void resize(Widget w, XtPointer data, XEvent * event)
 {
 #if defined(DEBUG)
     if (debuglevel == 7) {
@@ -920,7 +920,7 @@ void update_tmpstrins2( int num )
 /*
  * canvas event proc
  */
-void my_proc(Widget w, caddr_t data, XEvent * event)
+void my_proc(Widget w, XtPointer data, XEvent * event)
 {
     static int x, y, boxno, lineno, stringno, ellipno;
     static double wx1, wx2, wy1, wy2;
