@@ -173,7 +173,9 @@ void fext_routine( int gto, int feature, int abs_src, int abs_set, int abs_graph
 	double y1, y2;
 	int iy1, iy2;
 	char tbuf[1024];
-	float abscissa[MAXPLOT];
+	float *abscissa;
+
+	abscissa = (float *)malloc( maxplot*sizeof(float) );
 	
 	if( !isactive_graph( gto )	){
 		errwin("Graph for results must be active");
@@ -440,6 +442,7 @@ void fext_routine( int gto, int feature, int abs_src, int abs_set, int abs_graph
 			break;
 	}
 	setcomment( gto, ns, tbuf );
+	free( abscissa );
 	plotone( gto );
 }
 
