@@ -759,7 +759,7 @@ int readnxy(int gno, char *fn, FILE * fp)
 	cnt++;
 	s = NULL;
     }
-    if (cnt > MAXPLOT) {
+    if (cnt > maxplot) {
 	errmsg("Maximum number of columns exceeded, reading first 31");
 	cnt = 31;
     }
@@ -1416,8 +1416,8 @@ void alloc_blockdata(int ncols)
     if (blockdata != NULL) {
 	kill_blockdata();
     }
-    if (ncols < MAXPLOT) {
-	ncols = MAXPLOT;
+    if (ncols < maxplot) {
+	ncols = maxplot;
     }
     blockdata = (double **) malloc(ncols * sizeof(double *));
     if (blockdata != NULL) {
