@@ -227,7 +227,7 @@ int get_format_index(int f)
 {
     int i = 0;
 
-    while (f != format_types[i] && format_types[i] != 0)
+    while (f != format_types[i] && format_types[i] != FORMAT_INVALID)
 	i++;
     return i;
 }
