@@ -2,7 +2,7 @@
  * ACE/gr - Graphics for Exploratory Data Analysis
  *
  * Copyright (c) 1991-95 Paul J Turner, Portland, OR
- * Copyright (c) 1996-97 ACE/gr Development Team
+ * Copyright (c) 1996-98 ACE/gr Development Team
  * 
  * Currently maintained by Evgeny Stambulchik, Rehovot, Israel
  * 
@@ -107,7 +107,7 @@ int main(int argc, char *argv[])
 	fprintf(stderr, "%s v%d.%d.%d %s\n", version, 
 		MAJOR_REV, MINOR_REV, PATCHLEVEL, BETA_VER);
 	fprintf(stderr, "(C) Copyright 1991-1995 Paul J Turner\n");
-	fprintf(stderr, "(C) Copyright 1996-1997 ACE/gr Development Team\n");
+	fprintf(stderr, "(C) Copyright 1996-1998 ACE/gr Development Team\n");
 	fprintf(stderr, "All Rights Reserved\n");
 
 #ifndef NONE_GUI
@@ -377,8 +377,8 @@ int main(int argc, char *argv[])
 			usage(stderr, argv[0]);
 		    } else {
 			itmp = atoi(argv[i]);
-			if (itmp < MAXPLOT) {
-			    itmp = MAXPLOT;
+			if (itmp < maxplot) {
+			    itmp = maxplot;
 			}
 			alloc_blockdata(itmp);
 		    }
