@@ -26,7 +26,6 @@
 #include "motifinc.h"
 
 #define SPAGESIZE 30
-#define NPAGES (MAXPLOT/SPAGESIZE)
 
 #define  STATUS_NULL 0
 #define  STATUS_KILL 1
@@ -66,7 +65,7 @@
 #define  STATUS_REGION_EVAL 204
 #define  STATUS_REGION_DEL 205
 
-static int npages = NPAGES;
+static int npages;
 
 #define getdx(gno, setn)    getcol(gno, setn, 2)
 #define getdy(gno, setn)    getcol(gno, setn, 3)
@@ -80,8 +79,8 @@ static Dimension status_minwidth = 0;
 static int curpage = 0;
 
 static Widget header_w;
-static Widget labx[MAXPLOT];
-static Widget laby[MAXPLOT];
+static Widget *labx;
+static Widget *laby;
 
 static Widget rc4, rc5, rc6;
 
@@ -348,7 +347,7 @@ static void adjust_status_proc(Widget w, XtPointer client_data,
 
     update_status_popup(NULL, NULL, NULL);
     XtVaGetValues (header_w, XmNwidth, &status_width, NULL);
-    for (i = 0; i < MAXPLOT; i++) {
+    for (i = 0; i < SPAGESIZE; i++) {
         XtVaGetValues (labx[i], XmNwidth, &tmp_width, NULL);
         if (tmp_width > status_width) {
             status_width = tmp_width;
@@ -978,7 +977,7 @@ void define_status_popup(Widget w, XtPointer client_data, XtPointer call_data)
 	status_sw = XtVaCreateManagedWidget("sw",
 			       xmScrolledWindowWidgetClass, status_panel,
 				     XmNscrollingPolicy, XmAUTOMATIC,
-				     XmNheight, 200,
+				     XmNheight, 300,
 				     NULL);
 	rc3 = XmCreateRowColumn(status_sw, "rc3", NULL, 0);
 	header_w = XtVaCreateManagedWidget("header", xmLabelWidgetClass, rc3,
@@ -986,7 +985,9 @@ void define_status_popup(Widget w, XtPointer client_data, XtPointer call_data)
 					   XmNfontList, xmf,
 					   XmNrecomputeSize, True,
 					   NULL);
-	for (i = 0; i < MAXPLOT; i++) {
+	labx = (Widget *)malloc( maxplot*sizeof(Widget) );
+	laby = (Widget *)malloc( maxplot*sizeof(Widget) );
+	for (i = 0; i < SPAGESIZE; i++) {
 	    labx[i] = XtVaCreateManagedWidget("X", xmLabelWidgetClass, rc3,
 				     XmNalignment, XmALIGNMENT_BEGINNING,
 					      XmNfontList, xmf,
