@@ -598,7 +598,7 @@ static void accept_ticklabel_proc(Widget w, XtPointer client_data, XtPointer cal
     case 1:
 	gstart = gstop = cg;
 	astart = 0;
-	astop = 5;
+	astop = MAXAXES - 1;
 	break;
     case 2:
 	gstart = 0;
@@ -609,7 +609,7 @@ static void accept_ticklabel_proc(Widget w, XtPointer client_data, XtPointer cal
 	gstart = 0;
 	gstop = maxgraph - 1;
 	astart = 0;
-	astop = 5;
+	astop = MAXAXES - 1;
 	break;
     default:
 	/* error */
@@ -1043,7 +1043,7 @@ static void accept_tickmark_proc(Widget w, XtPointer client_data, XtPointer call
     case 1:
 	gstart = gstop = cg;
 	astart = 0;
-	astop = 5;
+	astop = MAXAXES - 1;
 	break;
     case 2:
 	gstart = 0;
@@ -1054,7 +1054,7 @@ static void accept_tickmark_proc(Widget w, XtPointer client_data, XtPointer call
 	gstart = 0;
 	gstop = maxgraph - 1;
 	astart = 0;
-	astop = 5;
+	astop = MAXAXES - 1;
 	break;
     default:
 	/* error */
