@@ -52,7 +52,7 @@ void do_zoomy(Widget w, XtPointer client_data, XtPointer call_data);
 void do_select_point(Widget w, XtPointer client_data, XtPointer call_data);
 void do_clear_point(Widget w, XtPointer client_data, XtPointer call_data);
 void refresh(Widget w, XtPointer client_data, XmDrawingAreaCallbackStruct *cbs);
-void resize(Widget w, caddr_t data, XEvent * event);
+void resize(Widget w, XtPointer data, XEvent * event);
 void setpointer(int x, int y);
 void getpoints(int x, int y);
 void set_stack_message(void);
@@ -63,7 +63,7 @@ void draw_focus(int gno);
 void update_text_cursor(char *s, int x, int y, char *);
 void set_action(int act);
 void do_text_string(int op, int c);
-void my_proc(Widget w, caddr_t data, XEvent * event);
+void my_proc(Widget w, XtPointer data, XEvent * event);
 void do_select_area(void);
 void do_select_peri(void);
 void do_select_region(void);
